@@ -1,7 +1,6 @@
 import grpc
 import jwt  # pip install pyJWT, ATTENTION, no pip install jwt!!
 import time
-import os
 from retry import retry
 
 from . import auth_pb2
@@ -44,18 +43,12 @@ def is_recoverable(exception):
            grpc.StatusCode.PERMISSION_DENIED != exception.code()
 
 
-def connect():
-    connectTo(os.environ["BATCHX_ENDPOINT"], os.environ["BATCHX_TOKEN"], True);
-
 @retry(RecoverableException, delay=CALL_DELAY, backoff=CALL_BACKOFF, max_delay=CALL_MAX_DELAY, tries=MAX_TRIES)
-def connectTo(endpoint, token, secure):
+def connect(endpoint, token):
     global channel, bx_token, bx_endpoint
     if channel is None:
         try:
-            if secure:
-                channel = grpc.secure_channel(endpoint, grpc.ssl_channel_credentials())
-            else:
-                channel = grpc.insecure_channel(endpoint)
+            channel = grpc.secure_channel(endpoint, grpc.ssl_channel_credentials())
             grpc.channel_ready_future(channel).result(CHANNEL_TIMEOUT)
         except grpc.FutureTimeoutError as exc:
             channel = None
@@ -126,141 +119,21 @@ def login():
         raise Exception("Batchx token not set. Please run: bx.connect(<endpoint>, <token>)")
 
 
-from . import admin_pb2
-from . import admin_pb2_grpc
+from . import environment_pb2
+from . import environment_pb2_grpc
 
 
-class AdminService:
+class EnvironmentService:
 
-    def AddEnvironmentCredits(self, request):
+    def GetEnvironment(self, request):
         check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).AddEnvironmentCredits, request)
+        return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).GetEnvironment, request)
 
-    def CreateOrg(self, request):
-        check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateOrg, request)
+    def GetEnvironmentRequest(self, **kwargs):
+        return environment_pb2.GetEnvironmentRequest(**kwargs)
 
-    def CreateUser(self, request):
-        check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateUser, request)
-
-    def GetGlobalProperties(self, request):
-        check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).GetGlobalProperties, request)
-
-    def SetGlobalProperty(self, request):
-        check()
-        return make_call(admin_pb2_grpc.AdminServiceStub(channel).SetGlobalProperty, request)
-
-    def AddEnvironmentCreditsRequest(self, **kwargs):
-        return admin_pb2.AddEnvironmentCreditsRequest(**kwargs)
-
-    def AddEnvironmentCreditsResponse(self, **kwargs):
-        return admin_pb2.AddEnvironmentCreditsResponse(**kwargs)
-
-    def Assignment(self, **kwargs):
-        return admin_pb2.Assignment(**kwargs)
-
-    def CreateOrgRequest(self, **kwargs):
-        return admin_pb2.CreateOrgRequest(**kwargs)
-
-    def CreateOrgResponse(self, **kwargs):
-        return admin_pb2.CreateOrgResponse(**kwargs)
-
-    def CreateUserRequest(self, **kwargs):
-        return admin_pb2.CreateUserRequest(**kwargs)
-
-    def CreateUserResponse(self, **kwargs):
-        return admin_pb2.CreateUserResponse(**kwargs)
-
-    def GetGlobalPropertiesRequest(self, **kwargs):
-        return admin_pb2.GetGlobalPropertiesRequest(**kwargs)
-
-    def GetGlobalPropertiesResponse(self, **kwargs):
-        return admin_pb2.GetGlobalPropertiesResponse(**kwargs)
-
-    def SetGlobalPropertyRequest(self, **kwargs):
-        return admin_pb2.SetGlobalPropertyRequest(**kwargs)
-
-    def SetGlobalPropertyResponse(self, **kwargs):
-        return admin_pb2.SetGlobalPropertyResponse(**kwargs)
-
-
-from . import audit_pb2
-from . import audit_pb2_grpc
-
-
-class AuditService:
-
-    def ListEvents(self, request):
-        check()
-        return make_call(audit_pb2_grpc.AuditServiceStub(channel).ListEvents, request)
-
-    def Event(self, **kwargs):
-        return audit_pb2.Event(**kwargs)
-
-    def ListEventsRequest(self, **kwargs):
-        return audit_pb2.ListEventsRequest(**kwargs)
-
-    def ListEventsResponse(self, **kwargs):
-        return audit_pb2.ListEventsResponse(**kwargs)
-
-
-from . import auth_pb2
-from . import auth_pb2_grpc
-
-
-class AuthService:
-
-    def ConfirmForgotPassword(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ConfirmForgotPassword, request)
-
-    def ForgotPassword(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ForgotPassword, request)
-
-    def Login(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).Login, request)
-
-    def RefreshToken(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).RefreshToken, request)
-
-    def RevokeRefreshToken(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).RevokeRefreshToken, request)
-
-    def ConfirmForgotPasswordRequest(self, **kwargs):
-        return auth_pb2.ConfirmForgotPasswordRequest(**kwargs)
-
-    def ConfirmForgotPasswordResponse(self, **kwargs):
-        return auth_pb2.ConfirmForgotPasswordResponse(**kwargs)
-
-    def ForgotPasswordRequest(self, **kwargs):
-        return auth_pb2.ForgotPasswordRequest(**kwargs)
-
-    def ForgotPasswordResponse(self, **kwargs):
-        return auth_pb2.ForgotPasswordResponse(**kwargs)
-
-    def LoginRequest(self, **kwargs):
-        return auth_pb2.LoginRequest(**kwargs)
-
-    def LoginResponse(self, **kwargs):
-        return auth_pb2.LoginResponse(**kwargs)
-
-    def RefreshTokenRequest(self, **kwargs):
-        return auth_pb2.RefreshTokenRequest(**kwargs)
-
-    def RefreshTokenResponse(self, **kwargs):
-        return auth_pb2.RefreshTokenResponse(**kwargs)
-
-    def RevokeRefreshTokenRequest(self, **kwargs):
-        return auth_pb2.RevokeRefreshTokenRequest(**kwargs)
-
-    def RevokeRefreshTokenResponse(self, **kwargs):
-        return auth_pb2.RevokeRefreshTokenResponse(**kwargs)
+    def GetEnvironmentResponse(self, **kwargs):
+        return environment_pb2.GetEnvironmentResponse(**kwargs)
 
 
 from . import common_pb2
@@ -297,6 +170,115 @@ class CommonService:
         return common_pb2.User(**kwargs)
 
 
+from . import health_pb2
+from . import health_pb2_grpc
+
+
+class HealthService:
+
+    def HealthCheckRequest(self, **kwargs):
+        return health_pb2.HealthCheckRequest(**kwargs)
+
+    def HealthCheckResponse(self, **kwargs):
+        return health_pb2.HealthCheckResponse(**kwargs)
+
+
+from . import tag_pb2
+from . import tag_pb2_grpc
+
+
+class TagService:
+
+    def CreateTag(self, request):
+        check()
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).CreateTag, request)
+
+    def DeleteTag(self, request):
+        check()
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).DeleteTag, request)
+
+    def DisableTag(self, request):
+        check()
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).DisableTag, request)
+
+    def GetTag(self, request):
+        check()
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).GetTag, request)
+
+    def ListEnvironmentTags(self, request):
+        check()
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).ListEnvironmentTags, request)
+
+    def UpdateTag(self, request):
+        check()
+        return make_call(tag_pb2_grpc.TagServiceStub(channel).UpdateTag, request)
+
+    def CreateTagRequest(self, **kwargs):
+        return tag_pb2.CreateTagRequest(**kwargs)
+
+    def CreateTagResponse(self, **kwargs):
+        return tag_pb2.CreateTagResponse(**kwargs)
+
+    def DeleteTagRequest(self, **kwargs):
+        return tag_pb2.DeleteTagRequest(**kwargs)
+
+    def DeleteTagResponse(self, **kwargs):
+        return tag_pb2.DeleteTagResponse(**kwargs)
+
+    def DisableTagRequest(self, **kwargs):
+        return tag_pb2.DisableTagRequest(**kwargs)
+
+    def DisableTagResponse(self, **kwargs):
+        return tag_pb2.DisableTagResponse(**kwargs)
+
+    def GetTagRequest(self, **kwargs):
+        return tag_pb2.GetTagRequest(**kwargs)
+
+    def GetTagResponse(self, **kwargs):
+        return tag_pb2.GetTagResponse(**kwargs)
+
+    def ListEnvironmentTagsRequest(self, **kwargs):
+        return tag_pb2.ListEnvironmentTagsRequest(**kwargs)
+
+    def ListEnvironmentTagsResponse(self, **kwargs):
+        return tag_pb2.ListEnvironmentTagsResponse(**kwargs)
+
+    def Tag(self, **kwargs):
+        return tag_pb2.Tag(**kwargs)
+
+    def TagCoordinates(self, **kwargs):
+        return tag_pb2.TagCoordinates(**kwargs)
+
+    def TagData(self, **kwargs):
+        return tag_pb2.TagData(**kwargs)
+
+    def UpdateTagRequest(self, **kwargs):
+        return tag_pb2.UpdateTagRequest(**kwargs)
+
+    def UpdateTagResponse(self, **kwargs):
+        return tag_pb2.UpdateTagResponse(**kwargs)
+
+
+from . import audit_pb2
+from . import audit_pb2_grpc
+
+
+class AuditService:
+
+    def ListEvents(self, request):
+        check()
+        return make_call(audit_pb2_grpc.AuditServiceStub(channel).ListEvents, request)
+
+    def Event(self, **kwargs):
+        return audit_pb2.Event(**kwargs)
+
+    def ListEventsRequest(self, **kwargs):
+        return audit_pb2.ListEventsRequest(**kwargs)
+
+    def ListEventsResponse(self, **kwargs):
+        return audit_pb2.ListEventsResponse(**kwargs)
+
+
 from . import docker_pb2
 from . import docker_pb2_grpc
 
@@ -307,21 +289,14 @@ class DockerService:
         return docker_pb2.DockerImageCoordinates(**kwargs)
 
 
-from . import environment_pb2
-from . import environment_pb2_grpc
+from . import profile_pb2
+from . import profile_pb2_grpc
 
 
-class EnvironmentService:
+class ProfileService:
 
-    def GetEnvironment(self, request):
-        check()
-        return make_call(environment_pb2_grpc.EnvironmentServiceStub(channel).GetEnvironment, request)
-
-    def GetEnvironmentRequest(self, **kwargs):
-        return environment_pb2.GetEnvironmentRequest(**kwargs)
-
-    def GetEnvironmentResponse(self, **kwargs):
-        return environment_pb2.GetEnvironmentResponse(**kwargs)
+    def Profile(self, **kwargs):
+        return profile_pb2.Profile(**kwargs)
 
 
 from . import filesystem_pb2
@@ -482,111 +457,31 @@ class FilesystemService:
         return filesystem_pb2.UploadPresignedResponse(**kwargs)
 
 
-from . import health_pb2
-from . import health_pb2_grpc
+from . import user_pb2
+from . import user_pb2_grpc
 
 
-class HealthService:
+class UserService:
 
-    def HealthCheckRequest(self, **kwargs):
-        return health_pb2.HealthCheckRequest(**kwargs)
-
-    def HealthCheckResponse(self, **kwargs):
-        return health_pb2.HealthCheckResponse(**kwargs)
-
-
-from . import image_pb2
-from . import image_pb2_grpc
-
-
-class ImageService:
-
-    def CloneImage(self, request):
+    def GetUser(self, request):
         check()
-        return make_call(image_pb2_grpc.ImageServiceStub(channel).CloneImage, request)
+        return make_call(user_pb2_grpc.UserServiceStub(channel).GetUser, request)
 
-    def DeleteImage(self, request):
+    def UpdateUser(self, request):
         check()
-        return make_call(image_pb2_grpc.ImageServiceStub(channel).DeleteImage, request)
+        return make_call(user_pb2_grpc.UserServiceStub(channel).UpdateUser, request)
 
-    def GetImage(self, request):
-        check()
-        return make_call(image_pb2_grpc.ImageServiceStub(channel).GetImage, request)
+    def GetUserRequest(self, **kwargs):
+        return user_pb2.GetUserRequest(**kwargs)
 
-    def GetPushCredentials(self, request):
-        check()
-        return make_call(image_pb2_grpc.ImageServiceStub(channel).GetPushCredentials, request)
+    def GetUserResponse(self, **kwargs):
+        return user_pb2.GetUserResponse(**kwargs)
 
-    def ImportImage(self, request):
-        check()
-        return make_call(image_pb2_grpc.ImageServiceStub(channel).ImportImage, request)
+    def UpdateUserRequest(self, **kwargs):
+        return user_pb2.UpdateUserRequest(**kwargs)
 
-    def ListImages(self, request):
-        check()
-        return make_call(image_pb2_grpc.ImageServiceStub(channel).ListImages, request)
-
-    def SearchImages(self, request):
-        check()
-        return make_call(image_pb2_grpc.ImageServiceStub(channel).SearchImages, request)
-
-    def ShareImage(self, request):
-        check()
-        return make_call(image_pb2_grpc.ImageServiceStub(channel).ShareImage, request)
-
-    def TagImage(self, request):
-        check()
-        return make_call(image_pb2_grpc.ImageServiceStub(channel).TagImage, request)
-
-    def CloneImageRequest(self, **kwargs):
-        return image_pb2.CloneImageRequest(**kwargs)
-
-    def CloneImageResponse(self, **kwargs):
-        return image_pb2.CloneImageResponse(**kwargs)
-
-    def DeleteImageRequest(self, **kwargs):
-        return image_pb2.DeleteImageRequest(**kwargs)
-
-    def GetImageRequest(self, **kwargs):
-        return image_pb2.GetImageRequest(**kwargs)
-
-    def GetImageResponse(self, **kwargs):
-        return image_pb2.GetImageResponse(**kwargs)
-
-    def GetPushCredentialsRequest(self, **kwargs):
-        return image_pb2.GetPushCredentialsRequest(**kwargs)
-
-    def GetPushCredentialsResponse(self, **kwargs):
-        return image_pb2.GetPushCredentialsResponse(**kwargs)
-
-    def Image(self, **kwargs):
-        return image_pb2.Image(**kwargs)
-
-    def ImportImageRequest(self, **kwargs):
-        return image_pb2.ImportImageRequest(**kwargs)
-
-    def ListImagesRequest(self, **kwargs):
-        return image_pb2.ListImagesRequest(**kwargs)
-
-    def ListImagesResponse(self, **kwargs):
-        return image_pb2.ListImagesResponse(**kwargs)
-
-    def SearchImagesRequest(self, **kwargs):
-        return image_pb2.SearchImagesRequest(**kwargs)
-
-    def SearchImagesResponse(self, **kwargs):
-        return image_pb2.SearchImagesResponse(**kwargs)
-
-    def ShareImageRequest(self, **kwargs):
-        return image_pb2.ShareImageRequest(**kwargs)
-
-    def ShareImageResponse(self, **kwargs):
-        return image_pb2.ShareImageResponse(**kwargs)
-
-    def TagImageRequest(self, **kwargs):
-        return image_pb2.TagImageRequest(**kwargs)
-
-    def TagImageResponse(self, **kwargs):
-        return image_pb2.TagImageResponse(**kwargs)
+    def UpdateUserResponse(self, **kwargs):
+        return user_pb2.UpdateUserResponse(**kwargs)
 
 
 from . import job_pb2
@@ -755,14 +650,158 @@ class JobService:
         return job_pb2.Workflow(**kwargs)
 
 
-from . import log_pb2
-from . import log_pb2_grpc
+from . import image_pb2
+from . import image_pb2_grpc
 
 
-class LogService:
+class ImageService:
 
-    def LogRecord(self, **kwargs):
-        return log_pb2.LogRecord(**kwargs)
+    def CloneImage(self, request):
+        check()
+        return make_call(image_pb2_grpc.ImageServiceStub(channel).CloneImage, request)
+
+    def DeleteImage(self, request):
+        check()
+        return make_call(image_pb2_grpc.ImageServiceStub(channel).DeleteImage, request)
+
+    def GetImage(self, request):
+        check()
+        return make_call(image_pb2_grpc.ImageServiceStub(channel).GetImage, request)
+
+    def GetPushCredentials(self, request):
+        check()
+        return make_call(image_pb2_grpc.ImageServiceStub(channel).GetPushCredentials, request)
+
+    def ImportImage(self, request):
+        check()
+        return make_call(image_pb2_grpc.ImageServiceStub(channel).ImportImage, request)
+
+    def ListImages(self, request):
+        check()
+        return make_call(image_pb2_grpc.ImageServiceStub(channel).ListImages, request)
+
+    def SearchImages(self, request):
+        check()
+        return make_call(image_pb2_grpc.ImageServiceStub(channel).SearchImages, request)
+
+    def ShareImage(self, request):
+        check()
+        return make_call(image_pb2_grpc.ImageServiceStub(channel).ShareImage, request)
+
+    def TagImage(self, request):
+        check()
+        return make_call(image_pb2_grpc.ImageServiceStub(channel).TagImage, request)
+
+    def CloneImageRequest(self, **kwargs):
+        return image_pb2.CloneImageRequest(**kwargs)
+
+    def CloneImageResponse(self, **kwargs):
+        return image_pb2.CloneImageResponse(**kwargs)
+
+    def DeleteImageRequest(self, **kwargs):
+        return image_pb2.DeleteImageRequest(**kwargs)
+
+    def GetImageRequest(self, **kwargs):
+        return image_pb2.GetImageRequest(**kwargs)
+
+    def GetImageResponse(self, **kwargs):
+        return image_pb2.GetImageResponse(**kwargs)
+
+    def GetPushCredentialsRequest(self, **kwargs):
+        return image_pb2.GetPushCredentialsRequest(**kwargs)
+
+    def GetPushCredentialsResponse(self, **kwargs):
+        return image_pb2.GetPushCredentialsResponse(**kwargs)
+
+    def Image(self, **kwargs):
+        return image_pb2.Image(**kwargs)
+
+    def ImportImageRequest(self, **kwargs):
+        return image_pb2.ImportImageRequest(**kwargs)
+
+    def ListImagesRequest(self, **kwargs):
+        return image_pb2.ListImagesRequest(**kwargs)
+
+    def ListImagesResponse(self, **kwargs):
+        return image_pb2.ListImagesResponse(**kwargs)
+
+    def SearchImagesRequest(self, **kwargs):
+        return image_pb2.SearchImagesRequest(**kwargs)
+
+    def SearchImagesResponse(self, **kwargs):
+        return image_pb2.SearchImagesResponse(**kwargs)
+
+    def ShareImageRequest(self, **kwargs):
+        return image_pb2.ShareImageRequest(**kwargs)
+
+    def ShareImageResponse(self, **kwargs):
+        return image_pb2.ShareImageResponse(**kwargs)
+
+    def TagImageRequest(self, **kwargs):
+        return image_pb2.TagImageRequest(**kwargs)
+
+    def TagImageResponse(self, **kwargs):
+        return image_pb2.TagImageResponse(**kwargs)
+
+
+from . import admin_pb2
+from . import admin_pb2_grpc
+
+
+class AdminService:
+
+    def AddEnvironmentCredits(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).AddEnvironmentCredits, request)
+
+    def CreateOrg(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateOrg, request)
+
+    def CreateUser(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).CreateUser, request)
+
+    def GetGlobalProperties(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).GetGlobalProperties, request)
+
+    def SetGlobalProperty(self, request):
+        check()
+        return make_call(admin_pb2_grpc.AdminServiceStub(channel).SetGlobalProperty, request)
+
+    def AddEnvironmentCreditsRequest(self, **kwargs):
+        return admin_pb2.AddEnvironmentCreditsRequest(**kwargs)
+
+    def AddEnvironmentCreditsResponse(self, **kwargs):
+        return admin_pb2.AddEnvironmentCreditsResponse(**kwargs)
+
+    def Assignment(self, **kwargs):
+        return admin_pb2.Assignment(**kwargs)
+
+    def CreateOrgRequest(self, **kwargs):
+        return admin_pb2.CreateOrgRequest(**kwargs)
+
+    def CreateOrgResponse(self, **kwargs):
+        return admin_pb2.CreateOrgResponse(**kwargs)
+
+    def CreateUserRequest(self, **kwargs):
+        return admin_pb2.CreateUserRequest(**kwargs)
+
+    def CreateUserResponse(self, **kwargs):
+        return admin_pb2.CreateUserResponse(**kwargs)
+
+    def GetGlobalPropertiesRequest(self, **kwargs):
+        return admin_pb2.GetGlobalPropertiesRequest(**kwargs)
+
+    def GetGlobalPropertiesResponse(self, **kwargs):
+        return admin_pb2.GetGlobalPropertiesResponse(**kwargs)
+
+    def SetGlobalPropertyRequest(self, **kwargs):
+        return admin_pb2.SetGlobalPropertyRequest(**kwargs)
+
+    def SetGlobalPropertyResponse(self, **kwargs):
+        return admin_pb2.SetGlobalPropertyResponse(**kwargs)
 
 
 from . import organization_pb2
@@ -849,14 +888,88 @@ class PictureService:
         return picture_pb2.UploadResponse(**kwargs)
 
 
-from . import profile_pb2
-from . import profile_pb2_grpc
+from . import token_pb2
+from . import token_pb2_grpc
 
 
-class ProfileService:
+class TokenService:
 
-    def Profile(self, **kwargs):
-        return profile_pb2.Profile(**kwargs)
+    def AddToken(self, request):
+        check()
+        return make_call(token_pb2_grpc.TokenServiceStub(channel).AddToken, request)
+
+    def AddTokenRequest(self, **kwargs):
+        return token_pb2.AddTokenRequest(**kwargs)
+
+    def AddTokenResponse(self, **kwargs):
+        return token_pb2.AddTokenResponse(**kwargs)
+
+
+from . import auth_pb2
+from . import auth_pb2_grpc
+
+
+class AuthService:
+
+    def ConfirmForgotPassword(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ConfirmForgotPassword, request)
+
+    def ForgotPassword(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ForgotPassword, request)
+
+    def Login(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).Login, request)
+
+    def RefreshToken(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).RefreshToken, request)
+
+    def RevokeRefreshToken(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).RevokeRefreshToken, request)
+
+    def ConfirmForgotPasswordRequest(self, **kwargs):
+        return auth_pb2.ConfirmForgotPasswordRequest(**kwargs)
+
+    def ConfirmForgotPasswordResponse(self, **kwargs):
+        return auth_pb2.ConfirmForgotPasswordResponse(**kwargs)
+
+    def ForgotPasswordRequest(self, **kwargs):
+        return auth_pb2.ForgotPasswordRequest(**kwargs)
+
+    def ForgotPasswordResponse(self, **kwargs):
+        return auth_pb2.ForgotPasswordResponse(**kwargs)
+
+    def LoginRequest(self, **kwargs):
+        return auth_pb2.LoginRequest(**kwargs)
+
+    def LoginResponse(self, **kwargs):
+        return auth_pb2.LoginResponse(**kwargs)
+
+    def RefreshTokenRequest(self, **kwargs):
+        return auth_pb2.RefreshTokenRequest(**kwargs)
+
+    def RefreshTokenResponse(self, **kwargs):
+        return auth_pb2.RefreshTokenResponse(**kwargs)
+
+    def RevokeRefreshTokenRequest(self, **kwargs):
+        return auth_pb2.RevokeRefreshTokenRequest(**kwargs)
+
+    def RevokeRefreshTokenResponse(self, **kwargs):
+        return auth_pb2.RevokeRefreshTokenResponse(**kwargs)
+
+
+from . import log_pb2
+from . import log_pb2_grpc
+
+
+class LogService:
+
+    def LogRecord(self, **kwargs):
+        return log_pb2.LogRecord(**kwargs)
 
 
 from . import provider_pb2
@@ -908,123 +1021,3 @@ class ProviderService:
     def Payout(self, **kwargs):
         return provider_pb2.Payout(**kwargs)
 
-
-from . import tag_pb2
-from . import tag_pb2_grpc
-
-
-class TagService:
-
-    def CreateTag(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).CreateTag, request)
-
-    def DeleteTag(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).DeleteTag, request)
-
-    def DisableTag(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).DisableTag, request)
-
-    def GetTag(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).GetTag, request)
-
-    def ListEnvironmentTags(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).ListEnvironmentTags, request)
-
-    def UpdateTag(self, request):
-        check()
-        return make_call(tag_pb2_grpc.TagServiceStub(channel).UpdateTag, request)
-
-    def CreateTagRequest(self, **kwargs):
-        return tag_pb2.CreateTagRequest(**kwargs)
-
-    def CreateTagResponse(self, **kwargs):
-        return tag_pb2.CreateTagResponse(**kwargs)
-
-    def DeleteTagRequest(self, **kwargs):
-        return tag_pb2.DeleteTagRequest(**kwargs)
-
-    def DeleteTagResponse(self, **kwargs):
-        return tag_pb2.DeleteTagResponse(**kwargs)
-
-    def DisableTagRequest(self, **kwargs):
-        return tag_pb2.DisableTagRequest(**kwargs)
-
-    def DisableTagResponse(self, **kwargs):
-        return tag_pb2.DisableTagResponse(**kwargs)
-
-    def GetTagRequest(self, **kwargs):
-        return tag_pb2.GetTagRequest(**kwargs)
-
-    def GetTagResponse(self, **kwargs):
-        return tag_pb2.GetTagResponse(**kwargs)
-
-    def ListEnvironmentTagsRequest(self, **kwargs):
-        return tag_pb2.ListEnvironmentTagsRequest(**kwargs)
-
-    def ListEnvironmentTagsResponse(self, **kwargs):
-        return tag_pb2.ListEnvironmentTagsResponse(**kwargs)
-
-    def Tag(self, **kwargs):
-        return tag_pb2.Tag(**kwargs)
-
-    def TagCoordinates(self, **kwargs):
-        return tag_pb2.TagCoordinates(**kwargs)
-
-    def TagData(self, **kwargs):
-        return tag_pb2.TagData(**kwargs)
-
-    def UpdateTagRequest(self, **kwargs):
-        return tag_pb2.UpdateTagRequest(**kwargs)
-
-    def UpdateTagResponse(self, **kwargs):
-        return tag_pb2.UpdateTagResponse(**kwargs)
-
-
-from . import token_pb2
-from . import token_pb2_grpc
-
-
-class TokenService:
-
-    def AddToken(self, request):
-        check()
-        return make_call(token_pb2_grpc.TokenServiceStub(channel).AddToken, request)
-
-    def AddTokenRequest(self, **kwargs):
-        return token_pb2.AddTokenRequest(**kwargs)
-
-    def AddTokenResponse(self, **kwargs):
-        return token_pb2.AddTokenResponse(**kwargs)
-
-
-from . import user_pb2
-from . import user_pb2_grpc
-
-
-class UserService:
-
-    def GetUser(self, request):
-        check()
-        return make_call(user_pb2_grpc.UserServiceStub(channel).GetUser, request)
-
-    def UpdateUser(self, request):
-        check()
-        return make_call(user_pb2_grpc.UserServiceStub(channel).UpdateUser, request)
-
-    def GetUserRequest(self, **kwargs):
-        return user_pb2.GetUserRequest(**kwargs)
-
-    def GetUserResponse(self, **kwargs):
-        return user_pb2.GetUserResponse(**kwargs)
-
-    def UpdateUserRequest(self, **kwargs):
-        return user_pb2.UpdateUserRequest(**kwargs)
-
-    def UpdateUserResponse(self, **kwargs):
-        return user_pb2.UpdateUserResponse(**kwargs)
-
